@@ -20,7 +20,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- * function: url_init to intialize a new url object
+ * function: url_init to initialize a new url object
  */
 
 typedef struct _url_t {
@@ -40,5 +40,7 @@ void url_purge(void);
 void url_dump(void);
 int url_count_inline(const wchar_t *line);
 int url_len_inline(const wchar_t *value);
+wchar_t* url_find_closing_bracket(const wchar_t *start);
+wchar_t *url_find_closing_parentheses(const wchar_t *start);
 
 #endif // !defined( URL_H )
