@@ -23,23 +23,33 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include "main.h"
 
+int is_number(const char *str) {
+    while (*str) {
+        if (!isdigit(*str)) return 0;
+        str++;
+    }
+    return 1;
+}
+
 void usage() {
     fprintf(stderr, "%s", "Usage: mdp [OPTION]... [FILE]\n");
     fprintf(stderr, "%s", "A command-line based markdown presentation tool.\n\n");
+    fprintf(stderr, "%s", "  -c, --nocodebg    don't change the background color of code blocks\n");
     fprintf(stderr, "%s", "  -d, --debug       enable debug messages on STDERR\n");
     fprintf(stderr, "%s", "                    add it multiple times to increases debug level\n");
     fprintf(stderr, "%s", "  -e, --expand      enable character entity expansion\n");
     fprintf(stderr, "%s", "  -f, --nofade      disable color fading in 256 color mode\n");
     fprintf(stderr, "%s", "  -h, --help        display this help and exit\n");
     fprintf(stderr, "%s", "  -i, --invert      swap black and white color\n");
+    fprintf(stderr, "%s", "  -j N, --jump N    jump to slide N\n");
     fprintf(stderr, "%s", "  -t, --notrans     disable transparency in transparent terminal\n");
     fprintf(stderr, "%s", "  -s, --noslidenum  do not show slide number at the bottom\n");
     fprintf(stderr, "%s", "  -v, --version     display the version number and license\n");
     fprintf(stderr, "%s", "  -x, --noslidemax  show slide number, but not total number of slides\n");
-    fprintf(stderr, "%s", "  -c, --nocodebg    don't change the background color of code blocks\n");
     fprintf(stderr, "%s", "\nWith no FILE, or when FILE is -, read standard input.\n\n");
     exit(EXIT_FAILURE);
 }
@@ -66,33 +76,43 @@ int main(int argc, char *argv[]) {
 
     // define command-line options
     struct option longopts[] = {
-        { "debug",      no_argument, 0, 'd' },
-        { "expand",     no_argument, 0, 'e' },
-        { "nofade",     no_argument, 0, 'f' },
-        { "help",       no_argument, 0, 'h' },
-        { "invert",     no_argument, 0, 'i' },
-        { "notrans",    no_argument, 0, 't' },
-        { "version",    no_argument, 0, 'v' },
-        { "noslidenum", no_argument, 0, 's' },
-        { "noslidemax", no_argument, 0, 'x' },
-        { "nocodebg",   no_argument, 0, 'c' },
+        { "nocodebg",   no_argument,       0, 'c' },
+        { "debug",      no_argument,       0, 'd' },
+        { "expand",     no_argument,       0, 'e' },
+        { "nofade",     no_argument,       0, 'f' },
+        { "help",       no_argument,       0, 'h' },
+        { "invert",     no_argument,       0, 'i' },
+        { "jump",       required_argument, 0, 'j' },
+        { "notrans",    no_argument,       0, 't' },
+        { "version",    no_argument,       0, 'v' },
+        { "noslidenum", no_argument,       0, 's' },
+        { "noslidemax", no_argument,       0, 'x' },
         { 0, 0, 0, 0 }
     };
 
     // parse command-line options
     int opt, debug = 0;
-    while ((opt = getopt_long(argc, argv, ":defhitvsxc", longopts, NULL)) != -1) {
+    while ((opt = getopt_long(argc, argv, ":cdefhij:tvsx", longopts, NULL)) != -1) {
         switch(opt) {
+            case 'c': nocodebg = 1; break;
             case 'd': debug += 1;   break;
             case 'e': noexpand = 0; break;
             case 'f': nofade = 1;   break;
             case 'h': usage();      break;
             case 'i': invert = 1;   break;
+            case 'j':
+                if(!is_number(optarg)) {
+                    fprintf(stderr, "%s: '%s' is not a valid number\n", argv[0], optarg);
+                    usage();
+                    break;
+                }
+                reload = atoi(optarg);
+                noreload = 0;
+                break;
             case 't': notrans = 1;  break;
             case 'v': version();    break;
             case 's': slidenum = 0; break;
             case 'x': slidenum = 1; break;
-            case 'c': nocodebg = 1; break;
             case ':': fprintf(stderr, "%s: '%c' requires an argument\n", argv[0], optopt); usage(); break;
             case '?':
             default : fprintf(stderr, "%s: option '%c' is invalid\n", argv[0], optopt); usage(); break;
